<?php
	/*------------------------------------------------------------------------------
   $Id$

   AbanteCart, Ideal OpenSource Ecommerce Solution
   http://www.AbanteCart.com

   Copyright © 2011 Belavier Commerce LLC

   This source file is subject to Open Software License (OSL 3.0)
   License details is bundled with this package in the file LICENSE.txt.
   It is also available at this URL:
   <http://www.opensource.org/licenses/OSL-3.0>

  UPGRADE NOTE:
	Do not edit or add to this file if you wish to upgrade AbanteCart to newer
	versions in the future. If you wish to customize AbanteCart for your
	needs please refer to http://www.AbanteCart.com for more information.
 ------------------------------------------------------------------------------*/
	if (!defined('DIR_CORE')) {
		header('Location: static_pages/');
	}

class ModelExtensionRewardPoints extends Model {

	public function getMethod($address) {
		$this->load->language('reward_points/reward_points');

		if ($this->config->get('reward_points_status')) {
			$status = TRUE;
		} else {
			$status = FALSE;
		}

		$method_data = array();

		if ($status) {
			$method_data = array(
				'id'         => 'reward_points',
				'title'      => $this->language->get('text_reward_points'),
				'sort_order' => 1000
			);
		}

		return $method_data;
	}

	public function getRewardPoints($customer_group_id = null, $object_name = null, $object_id = null) {
		$q = 'SELECT * FROM ' . DB_PREFIX . 'reward_points';

		$where = array();
		if ( $object_name ) {
			$where[] = 'object_name = "' . $this->db->escape($object_name) . '"';

			if ( $object_id ) {
				$where[] = 'object_id = ' . (int) $object_id;
			}
		}

		if ($customer_group_id) {
			$where[] = 'customer_group_id = ' . (int) $customer_group_id;
		}

		if ( !empty($where) ) {
			$q .= ' WHERE ' . implode(' AND ', $where);
		}

		$result = $this->db->query($q);

		return $result->row;
	}

	public function getProductManufacturerId($product_id) {
		$result = $this->db->query('
			SELECT manufacturer_id FROM ' . DB_PREFIX . 'products
			WHERE product_id = "' . (int) $product_id . '" LIMIT 1
		');

		if ( $result->num_rows > 0) {
			return $result->row['manufacturer_id'];
		}
		return false;
	}

	public function getProductCategories($product_id) {
		$q = $this->db->query('
			SELECT ptc.category_id, c.parent_id FROM ' . DB_PREFIX . 'products_to_categories ptc
			INNER JOIN ' . DB_PREFIX . 'categories c ON c.category_id = ptc.category_id
			WHERE product_id = "' . (int) $product_id . '"
		');

		$result = array();
		if ( $q->num_rows > 0) {
			foreach ( $q->rows as $v ) {
				$result[$v['category_id']] = $v['category_id'];
				$result[$v['parent_id']] = $v['parent_id'];
			}
		}
		return $result;
	}

	public function getCustomerRewardPoints($customer_id) {
		$result = $this->db->query('
			SELECT * FROM ' . DB_PREFIX . 'reward_points_customers
			WHERE customer_id = "' . (int) $customer_id . '" LIMIT 1'
		);

		if ( $result->num_rows > 0 ) {
			return $result->row;
		}
		return array();
	}

	public function setCustomerRewardPoints($customer_id, $points_amount) {

		return $this->db->query('
			REPLACE INTO ' . DB_PREFIX . 'reward_points_customers
			SET
				customer_id = "' . (int) $customer_id . '",
				points_amount = "' . (int) $points_amount. '",
				date_modified = NOW()
		');
	}

	public function insertCustomerRewardPoints($data) {

		if ( !isset($data['customer_id']) ) {
			return;
		}

		return $this->db->query('
			INSERT INTO ' . DB_PREFIX . 'reward_points_customers
			SET
				customer_id = "' . (int) $data['customer_id'] . '",
				points_amount = "' . (int) $data['points_amount'] . '",
				date_modified = NOW()
		');
	}

	public function updateCustomerRewardPoints($data) {

		if ( !isset($data['customer_id']) ) {
			return;
		}

		return $this->db->query('
			UPDATE ' . DB_PREFIX . 'reward_points_customers
			SET
				points_amount = "' . (int) $data['points_amount'] . '",
				date_modified = NOW()
			WHERE customer_id = "' . (int) $data['customer_id'] . '" LIMIT 1
		');
	}

	public function removeRewardPoints($data) {
		if ( ( !isset($data['object_name']) || !isset($data['object_id']) ) && !isset($data['reward_point_id']) ) {
			return;
		}

		$q = 'DELETE FROM ' . DB_PREFIX . 'reward_points';

		if ( isset($data['reward_point_id']) ) {
			$q .= ' WHERE reward_point_id = "' . (int) $data['reward_point_id'] . '"';
		} else {
			$q .= ' WHERE object_name = "' . $this->db->escape($data['object_name']) . '"
					AND object_id = "' . (int) $data['object_id'] . '"';
		}

		return $this->db->query($q);
	}

	public function getHistory($start = 0, $limit = 20) {

		if ($start < 0) {
			$start = 0;
		}

		$q = 'SELECT * FROM ' . DB_PREFIX . 'reward_points_history
			WHERE customer_id = "' . (int) $this->customer->getId() . '"
			ORDER BY date DESC
			LIMIT ' . (int) $start . ', ' . (int) $limit;

		$result = $this->db->query($q);

		if ( $result->num_rows ) {
			return $result->rows;
		}
		return array();
	}

	public function updateHistory($data) {
		return $this->db->query('
			INSERT INTO ' . DB_PREFIX . 'reward_points_history
			SET
				customer_id = "' . (int) $data['customer_id'] . '",
				amount = "' . (int) $data['amount'] . '",
				action = "' . $this->db->escape($data['action']) . '",
				source = "' . $this->db->escape($data['source']) . '",
				source_id = "' . (int) $data['source_id'] . '",
				comment = "' . $this->db->escape($data['comment']) . '",
				date = NOW()
		');
	}

	public function getTotalRows() {

		$result = $this->db->query(
			'SELECT COUNT(reward_points_history_id) as count
  			FROM ' . DB_PREFIX . 'reward_points_history
  			WHERE customer_id = "' . (int) $this->customer->getId() . '"'
		);
		if ( $result->num_rows ) {
			return (int) $result->row['count'];
		}
		return 0;
	}

	public function setRewardPointsOrder($data) {
		return $this->db->query(
			'INSERT INTO ' . DB_PREFIX . 'reward_points_orders
			SET
				order_id = "' . (int)$data['order_id'] . '",
				amount = "' . (int)$data['amount'] . '",
				action = "' . $this->db->escape($data['action']) . '"');
	}

	public function getRewardPointsOrder($order_id) {
		$result = $this->db->query(
			'SELECT * FROM ' . DB_PREFIX . 'reward_points_orders
			WHERE order_id = "' . (int)$order_id . '"'
		);

		if ( $result->num_rows ) {
			return $result->row;
		}
		return array();
	}
}